@@ -52,6 +52,10 @@ public:
 			return;
 
 		string answer = m.getArg(0);
+
+		if (answer[0] == '\001')
+			return;
+
 		irc::IRC* irc = Purple::getIM()->getIRC();
 		Request* request = Request::getFirstRequest();
 		if(!request)
@@ -300,6 +304,12 @@ Request* Request::addRequest(Request* request)
 	requests.push_back(request);
 	if(requests.size() == 1)
 		request->display();
+	else {
+		irc::IRC* irc = Purple::getIM()->getIRC();
+		nick->privmsg(irc->getUser(),
+		              "Hint: Received a new request (" + request->title + "). "
+		              "There are " + t2s(requests.size() - 1) + " requests in stack");
+	}
 
 	return request;
 }
@@ -483,7 +493,7 @@ void* Request::request_choice(const char *title, const char *primary,
 	while ((text = va_arg(choices, const char *)))
 	{
 		int val = va_arg(choices, int);
-		string tmp;
+		string tmp = text;
 
 		request->addField(new RequestFieldAction<PurpleRequestChoiceCb>(val, strlower(stringtok(tmp, "_ ")), text, (PurpleRequestChoiceCb)ok_cb, user_data));
 	}
