@@ -1,6 +1,6 @@
 /*
  * Minbif - IRC instant messaging gateway
- * Copyright(C) 2009-2010 Romain Bignon
+ * Copyright(C) 2009-2011 Romain Bignon
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
  */
 
 #include <cstring>
+#include <fnmatch.h>
 
 #include "core/caca_image.h"
 #include "irc/irc.h"
@@ -71,7 +72,8 @@ void IRC::m_who(Message message)
 		{
 			Nick* n = it->second;
 			string channame = "*";
-			if(arg.empty() || arg == "*" || arg == "0" || arg == n->getNickname() || n->getServer()->getServerName().find(arg) != string::npos)
+			if(arg.empty() || arg == "*" || arg == "0" || n->getServer()->getServerName().find(arg) != string::npos ||
+			   !fnmatch(arg.c_str(), n->getNickname().c_str(), FNM_NOESCAPE|FNM_CASEFOLD))
 			{
 				vector<ChanUser*> chans = n->getChannels();
 				if(!chans.empty())
@@ -325,7 +327,7 @@ void IRC::m_join(Message message)
 				string accid = channame.substr(1);
 				/* purple_url_decode() returns a static buffer, no free needed. */
 				string convname = purple_url_decode(stringtok(accid, ":").c_str());
-				string param = stringtok(parameters, ",");
+				string param = purple_url_decode(stringtok(parameters, ",").c_str());
 				if(accid.empty() || convname.empty())
 				{
 					user->send(Message(ERR_NOSUCHCHANNEL).setSender(this)
