@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 2009 Romain Bignon
+ * Copyright(C) 2009-2010 Romain Bignon
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,11 +26,6 @@
 
 class CacaImage;
 
-namespace im
-{
-	class Conversation;
-}
-
 namespace irc
 {
 	class Server;
@@ -56,6 +51,7 @@ namespace irc
 		static const char *nick_lc_chars;
 		static const char *nick_uc_chars;
 		static const size_t MAX_LENGTH = 29;
+		static const char* UMODES;
 		static string nickize(const string& n);
 
 		/** States of the user */
@@ -179,7 +175,10 @@ namespace irc
 
 		virtual bool retrieveInfo() const { return false; }
 
-		virtual string getStatusMessage() const { return ""; }
+		/** Get status.
+		 * @param away  if false, do not return anything if the buddy is away.
+		 */
+		virtual string getStatusMessage(bool away = false) const { return ""; }
 
 		void setFlag(unsigned flag) { flags |= flag; }
 		void delFlag(unsigned flag) { flags &= ~flag; }
@@ -194,20 +193,6 @@ namespace irc
 		virtual string getIconPath() const { return ""; }
 	};
 
-	class ConvNick : public Nick
-	{
-	public:
-		ConvNick(Server* server, string nickname, string identname, string hostname, string realname="");
-
-		/** Get the conversation associated to this nick */
-		virtual im::Conversation getConversation() const = 0;
-
-		/** Set the conversation associated. */
-		virtual void setConversation(const im::Conversation& c) = 0;
-
-		/** The ConvNick sends a message to someone. */
-		virtual void sendMessage(Nick* to, const string& text, bool action = false);
-	};
 
 }; /* namespace irc */
 
