@@ -66,13 +66,21 @@ DaemonForkServerPoll::DaemonForkServerPoll(Minbif* application, ConfigSection* c
 		setsid();
 
 		for (r=getdtablesize();r>=0;--r) close(r);
+
+		/* Redirect the default streams to /dev/null.
+		 * We hope that the descriptors will be 0, 1 and 2
+		 */
 		r=open("/dev/null",O_RDWR); /* open stdin */
-		dup(r); /* stdout */
-		dup(r); /* stderr */
+		(void)dup(r); /* stdout */
+		(void)dup(r); /* stderr */
 
 		umask(027);
 		string path = conf.GetSection("path")->GetItem("users")->String();
-		chdir(path.c_str());
+		if (chdir(path.c_str()) < 0)
+		{
+			b_log[W_ERR] << "Unable to change directory: " << strerror(errno);
+			throw ServerPollError();
+		}
 	}
 
 	struct addrinfo *addrinfo_bind, *res, hints;
@@ -167,8 +175,11 @@ bool DaemonForkServerPoll::new_client_cb(void*)
 		b_log[W_WARNING] << "Unable to create IPC socket for client: " << strerror(errno);
 		fds[0] = fds[1] = -1;
 	}
-	sock_make_nonblocking(fds[0]);
-	sock_make_nonblocking(fds[1]);
+	else
+	{
+		sock_make_nonblocking(fds[0]);
+		sock_make_nonblocking(fds[1]);
+	}
 
 	pid_t client_pid = fork();
 
@@ -338,6 +349,7 @@ bool DaemonForkServerPoll::ipc_read(void* data)
 				else
 					++it;
 
+			close(child->fd);
 			g_source_remove(child->read_id);
 			delete child->read_cb;
 			delete child;
@@ -349,6 +361,7 @@ bool DaemonForkServerPoll::ipc_read(void* data)
 			read_id = -1;
 			delete read_cb;
 			read_cb = NULL;
+			close(sock);
 			sock = -1;
 		}
 		return false;
@@ -435,17 +448,15 @@ bool DaemonForkServerPoll::ipc_send(const irc::Message& m)
 
 void DaemonForkServerPoll::log(size_t level, string msg) const
 {
-	if(msg.find("\n") != string::npos)
-		msg = msg.substr(0, msg.find("\n"));
-
 	string cmd = MSG_NOTICE;
 	if(level & W_DEBUG)
 		cmd = MSG_PRIVMSG;
 
 	if(irc)
-		irc->getUser()->send(irc::Message(cmd).setSender(irc)
-							     .setReceiver(irc->getUser())
-							     .addArg(msg));
+		for(string line; (line = stringtok(msg, "\n\r")).empty() == false;)
+			irc->getUser()->send(irc::Message(cmd).setSender(irc)
+								     .setReceiver(irc->getUser())
+								     .addArg(line));
 	else if(!(level & W_SNO))
 		std::cout << msg << std::endl;
 }
